@@ -18,6 +18,8 @@
 
 #include "renameassistant.h"
 #include "renameaction.h"
+#include "simplerefactoring.h"
+#include "renamefileaction.h"
 #include <language/duchain/duchainutils.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
@@ -32,17 +34,20 @@
 using namespace KDevelop;
 using namespace Cpp;
 
-RenameAssistant::RenameAssistant(KTextEditor::View *view) :
-m_documentUrl(IndexedString(view->document()->url())),
-m_isUseful(false),
-m_view(view)
-{}
+RenameAssistant::RenameAssistant(KTextEditor::View *view)
+: m_view(view)
+, m_isUseful(false)
+, m_renameFile(false)
+{
+
+}
 
 void RenameAssistant::reset() {
   m_oldDeclarationName = Identifier();
   m_newDeclarationRange.clear();
   m_oldDeclarationUses.clear();
   m_isUseful = false;
+  m_renameFile = false;
 }
 
 bool rangesConnect(const KTextEditor::Range &firstRange, const KTextEditor::Range &secondRange) {
@@ -53,33 +58,38 @@ bool rangesConnect(const KTextEditor::Range &firstRange, const KTextEditor::Rang
   return !firstRange.intersect(expanded).isEmpty();
 }
 
-Declaration* RenameAssistant::getValidDeclarationForChangedRange(KTextEditor::Range changed) {
+Declaration* RenameAssistant::getDeclarationForChangedRange(const KTextEditor::Range& changed) const
+{
   SimpleCursor cursor(changed.start());
 
-  Declaration* declaration = DUChainUtils::itemUnderCursor(m_documentUrl.toUrl(), cursor);
+  Declaration* declaration = DUChainUtils::itemUnderCursor(m_view->document()->url(), cursor);
 
   //If it's null we could be appending, but there's a case where appending gives a wrong decl
   //and not a null declaration ... "type var(init)", so check for that too
   if (!declaration || !rangesConnect(declaration->rangeInCurrentRevision().textRange(), changed))
-    declaration = DUChainUtils::itemUnderCursor(m_documentUrl.toUrl(), SimpleCursor(cursor.line, --cursor.column));
+    declaration = DUChainUtils::itemUnderCursor(m_view->document()->url(), SimpleCursor(cursor.line, --cursor.column));
 
   //In this case, we may either not have a decl at the cursor, or we got a decl, but are editing its use.
   //In either of those cases, give up and return 0
   if (!declaration || !rangesConnect(declaration->rangeInCurrentRevision().textRange(), changed))
     return 0;
 
+  return declaration;
+}
+
+bool RenameAssistant::shouldRenameUses(Declaration* declaration) const
+{
   //Now we know we're editing a declaration, but some declarations we don't offer a rename for
   //basically that's any declaration that wouldn't be fully renamed just by renaming its uses().
   if (declaration->internalContext() || declaration->isForwardDeclaration()) {
     //make an exception for non-class functions
     if(!declaration->isFunctionDeclaration() || dynamic_cast<ClassFunctionDeclaration*>(declaration))
-      return 0;
+      return false;
   }
-
-  return declaration;
+  return true;
 }
 
-void RenameAssistant::textChanged(KTextEditor::Range invocationRange, QString removedText) {
+void RenameAssistant::textChanged(const KTextEditor::Range& invocationRange, const QString& removedText) {
   clearActions();
 
   if (!m_view)
@@ -92,16 +102,22 @@ void RenameAssistant::textChanged(KTextEditor::Range invocationRange, QString re
     return;
   }
 
-  KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
+  const KUrl url = m_view->document()->url();
+  const IndexedString indexedUrl(url);
+  DUChainReadLocker lock;
 
   //If we've stopped editing m_newDeclarationRange, reset and see if there's another declaration being edited
   if (!m_newDeclarationRange.data() || !rangesConnect(m_newDeclarationRange->range().textRange(), invocationRange)) {
     reset();
 
-    if (Declaration* declAtCursor = getValidDeclarationForChangedRange(invocationRange)) {
+    Declaration* declAtCursor = getDeclarationForChangedRange(invocationRange);
+    if (!declAtCursor) {
+      // not editing a declaration
+      return;
+    }
+    if (shouldRenameUses(declAtCursor)) {
       QMap< IndexedString, QList<RangeInRevision> > declUses = declAtCursor->uses();
       if (declUses.size() > 0) {
-        
         for(QMap< IndexedString, QList< RangeInRevision > >::iterator it = declUses.begin(); it != declUses.end(); ++it)
         {
           foreach(RangeInRevision range, it.value())
@@ -112,32 +128,54 @@ void RenameAssistant::textChanged(KTextEditor::Range invocationRange, QString re
           }
         }
         
-        m_oldDeclarationName = declAtCursor->identifier();
         m_oldDeclarationUses = declUses;
-
-        KTextEditor::Range newRange = declAtCursor->rangeInCurrentRevision().textRange();
-        if (removedText.isEmpty() && newRange.intersect(invocationRange).isEmpty())
-          newRange = newRange.encompass(invocationRange); //if text was added to the ends, encompass it
-
-        m_newDeclarationRange.attach(new PersistentMovingRange(newRange, m_documentUrl, true));
       }
       else  return; //new declaration is use-less
+    } else if (SimpleRefactoring::shouldRenameFile(declAtCursor)) {
+      m_renameFile = true;
+    } else {
+      // not a valid declaration
+      return;
     }
-    else return; //not editing a declaration
+
+    m_oldDeclarationName = declAtCursor->identifier();
+    KTextEditor::Range newRange = declAtCursor->rangeInCurrentRevision().textRange();
+    if (removedText.isEmpty() && newRange.intersect(invocationRange).isEmpty()) {
+      newRange = newRange.encompass(invocationRange); //if text was added to the ends, encompass it
+    }
+
+    m_newDeclarationRange.attach(new PersistentMovingRange(newRange, indexedUrl, true));
   }
 
   //Unfortunately this happens when you make a selection including one end of the decl's range and replace it
-  if (removedText.isEmpty() && m_newDeclarationRange->range().textRange().intersect(invocationRange).isEmpty())
+  if (removedText.isEmpty() && m_newDeclarationRange->range().textRange().intersect(invocationRange).isEmpty()) {
     m_newDeclarationRange.attach( new PersistentMovingRange(
-        m_newDeclarationRange->range().textRange().encompass(invocationRange), m_documentUrl, true) );
+        m_newDeclarationRange->range().textRange().encompass(invocationRange), indexedUrl, true) );
+  }
 
   m_newDeclarationName = m_view->document()->text(m_newDeclarationRange->range().textRange());
 
-  if (m_newDeclarationName == m_oldDeclarationName.toString())
+  if (m_newDeclarationName == m_oldDeclarationName.toString()) {
     return;
+  }
+
+  if (m_renameFile && SimpleRefactoring::newFileName(url, m_newDeclarationName) == url.fileName()) {
+    // no change, don't do anything
+    return;
+  }
 
   m_isUseful = true;
-  addAction(IAssistantAction::Ptr(new RenameAction(m_oldDeclarationName, m_newDeclarationName, m_oldDeclarationUses)));
+
+  IAssistantAction::Ptr action;
+
+  if (m_renameFile) {
+    action.attach(new RenameFileAction(url, m_newDeclarationName));
+  } else {
+    action.attach(new RenameAction(m_oldDeclarationName, m_newDeclarationName,
+                                                     m_oldDeclarationUses));
+  }
+  connect(action.data(), SIGNAL(executed(IAssistantAction*)), SLOT(reset()));
+  addAction(action);
   emit actionsChanged();
 }
 
