@@ -179,7 +179,7 @@ QString print(const Cpp::ReferenceCountedMacroSet& set) {
 EnvironmentManager* EnvironmentManager::m_self = 0;
 
 EnvironmentManager::EnvironmentManager()
-  : m_simplifiedMatching(false), m_matchingLevel(Full),
+  : m_matchingLevel(Full), m_simplifiedMatching(false),
     m_macroDataRepository("macro repository"), m_stringSetRepository("string sets"), m_macroSetRepository()
 {
 }
@@ -295,7 +295,7 @@ bool EnvironmentFile::needsUpdate(const ParsingEnvironment* environment) const {
   return ParsingEnvironmentFile::needsUpdate(environment) || d_func()->m_includePathDependencies.needsUpdate();
 }
 
-EnvironmentFile::EnvironmentFile( IndexedString url, TopDUContext* topContext ) : ParsingEnvironmentFile(*new EnvironmentFileData(), url) {
+EnvironmentFile::EnvironmentFile( const IndexedString& url, TopDUContext* topContext ) : ParsingEnvironmentFile(*new EnvironmentFileData(), url) {
 
   d_func_dynamic()->setClassId(this);
   setLanguage(IndexedString("C++"));
