@@ -111,6 +111,8 @@ private slots:
   void testTemplates2();
   void testTemplates3();
   void testTemplates4();
+  void testSpecializationSelection();
+  void testSpecializationSelection2();
   void testTemplatesRebind();
   void testTemplatesRebind2();
   void testTemplateDefaultParameters();
@@ -118,12 +120,14 @@ private slots:
   void testFunctionTemplates();
   void testContextAssignment();
   void testSpecializedTemplates();
+  void testTemplatesSuper();
   void testFunctionDefinition();
   void testFunctionDefinition2();
   void testFunctionDefinition3();
   void testFunctionDefinition4();
   void testFunctionDefinition5();
   void testFunctionDefinition6();
+  void testFunctionDefinition7();
   void testMetaProgramming();
   void testMetaProgramming2();
   void testMetaProgramming3();
