@@ -35,7 +35,7 @@
 
 #include "typeutils.h"
 #include "templatedeclaration.h"
-#include "cppduchain.h""
+#include "cppduchain.h"
 
 using namespace KDevelop;
 using namespace Cpp;
@@ -842,13 +842,25 @@ void TestDUChain::testAuto()
     "auto a7(1.1d);\n"
     "auto a8(i);\n"
     "auto a9 /** test **/ (i);\n"
+    "auto a10(a2);\n"
+    "auto a11(a3);\n"
+    "auto a12(a4);\n"
+    "auto a13(a5);\n"
+    "auto a14(a6);\n"
+    "void f() {\n"
+    "  if (auto c1 = 0.0) {}\n"
+    "}\n"
+    "struct FOO {};\n"
+    "auto a15 = FOO{};\n"
+    "auto a16 = FOO{1};\n"
+
   );
   LockedTopDUContext top = parse(code, DumpAll);
   QVERIFY(top);
   DUChainReadLocker lock;
   QVERIFY(top->problems().isEmpty());
 
-  QCOMPARE(top->localDeclarations().count(), 10);
+  QCOMPARE(top->localDeclarations().count(), 19);
 
   Declaration* dec = top->localDeclarations().at(1);
   QVERIFY(dec->type<IntegralType>());
@@ -889,13 +901,25 @@ void TestDUChain::testAuto()
   QVERIFY(dec->type<IntegralType>());
   QCOMPARE(dec->type<IntegralType>()->dataType(), (uint) IntegralType::TypeDouble);
 
-  dec = top->localDeclarations().at(8);
-  QVERIFY(dec->type<IntegralType>());
-  QCOMPARE(dec->type<IntegralType>()->dataType(), (uint) IntegralType::TypeChar);
+  for (int i = 8; i < 15; ++i) {
+    dec = top->localDeclarations().at(i);
+    QVERIFY(dec->type<IntegralType>());
+    QCOMPARE(dec->type<IntegralType>()->dataType(), (uint) IntegralType::TypeChar);
+    QCOMPARE(dec->abstractType()->modifiers(), (quint64) AbstractType::NoModifiers);
+  }
 
-  dec = top->localDeclarations().at(9);
+  dec = top->localDeclarations().at(15)->internalContext()->childContexts().first()->findDeclarations(Identifier("c1")).first();
   QVERIFY(dec->type<IntegralType>());
-  QCOMPARE(dec->type<IntegralType>()->dataType(), (uint) IntegralType::TypeChar);
+  QCOMPARE(dec->type<IntegralType>()->dataType(), (uint) IntegralType::TypeDouble);
+
+  StructureType::Ptr foo = top->localDeclarations().at(16)->type<StructureType>();
+  QVERIFY(foo);
+
+  dec = top->localDeclarations().at(17);
+  QVERIFY(dec->abstractType()->equals(foo.constData()));
+
+  dec = top->localDeclarations().at(18);
+  QVERIFY(dec->abstractType()->equals(foo.constData()));
 }
 
 void TestDUChain::testNoexcept()
