@@ -65,6 +65,11 @@
 
 #include <interfaces/ilanguage.h>
 #include <interfaces/iuicontroller.h>
+#include <cpppreprocessenvironment.h>
+#include <language/checks/dataaccessrepository.h>
+#include <language/checks/controlflowgraph.h>
+#include <controlflowgraphbuilder.h>
+#include <usedecoratorvisitor.h>
 
 //#define DUMP_AST
 //#define DUMP_DUCHAIN
@@ -108,9 +113,9 @@ void CPPParseJob::setNeedUpdateEverything(bool need) {
   m_needUpdateEverything = need;
 }
 
-CPPParseJob::CPPParseJob( const KUrl &url,
+CPPParseJob::CPPParseJob( const IndexedString& url, ILanguageSupport* languageSupport,
                     PreprocessJob* parentPreprocessor )
-        : KDevelop::ParseJob( url ),
+        : KDevelop::ParseJob( url, languageSupport ),
         m_needUpdateEverything( false ),
         m_parentPreprocessor( parentPreprocessor ),
         m_session( new ParseSession ),
@@ -953,15 +958,13 @@ void CPPParseJob::setIncludeStack(const QStack< DocumentCursor > & includeStack)
   m_includeStack = includeStack;
 }
 
-TopDUContext::Features CPPParseJob::standardMinimumFeatures() const
-{
-    return TopDUContext::SimplifiedVisibleDeclarationsAndContexts;
-}
-
 TopDUContext::Features CPPParseJob::slaveMinimumFeatures() const
 {
-    TopDUContext::Features slaveMinimumFeatures = standardMinimumFeatures();
-    
+    TopDUContext::Features slaveMinimumFeatures = KDevelop::TopDUContext::Empty;
+    if (minimumFeatures() & TopDUContext::SimplifiedVisibleDeclarationsAndContexts) {
+      slaveMinimumFeatures = TopDUContext::SimplifiedVisibleDeclarationsAndContexts;
+    }
+
     if(minimumFeatures() & TopDUContext::Recursive)
       slaveMinimumFeatures = (TopDUContext::Features)(minimumFeatures() & (~TopDUContext::ForceUpdate));
     else if((minimumFeatures() & TopDUContext::VisibleDeclarationsAndContexts) == TopDUContext::VisibleDeclarationsAndContexts)
@@ -974,5 +977,21 @@ TopDUContext::Features CPPParseJob::slaveMinimumFeatures() const
     return (TopDUContext::Features)(slaveMinimumFeatures | TopDUContext::Recursive);
 }
 
+ControlFlowGraph* CPPParseJob::controlFlowGraph()
+{
+  ControlFlowGraph* ret = new ControlFlowGraph;
+  ControlFlowGraphBuilder flowvisitor(duChain(), m_session.data(), ret);
+  flowvisitor.run(m_session->topAstNode());
+  return ret;
+}
+
+DataAccessRepository* CPPParseJob::dataAccessInformation()
+{
+  DataAccessRepository* ret = new DataAccessRepository;
+  UseDecoratorVisitor visit(m_session.data(), ret);
+  visit.run(m_session->topAstNode());
+  return ret;
+}
+
 #include "cppparsejob.moc"
 
