@@ -75,6 +75,7 @@ private slots:
   void testCaseContext();
   void testCaseContextComplexExpression();
   void testCaseContextDifferentScope();
+  void testCaseContextConstants();
   void testUnaryOperators();
   void testBinaryOperators();
   void testDeclarationIsInitialization();
@@ -119,6 +120,7 @@ private slots:
   void testNamespaceCompletion();
   void testNamespaceAliasCompletion();
   void testNamespaceAliasCycleCompletion();
+  void testAfterNamespace();
   void testTemplateMemberAccess();
   void testTemplateArguments();
   void testTemplateFunction();
@@ -129,6 +131,7 @@ private slots:
   void testCompletionBehindTypedeffedConstructor();
   void testSubClassVisibility();
   void testSignalSlotCompletion();
+  void testSignalSlotExecution();
   void testStringProblem();
   void testArgumentList();
   void testStaticMethods();
@@ -149,6 +152,8 @@ private slots:
   void testAfterVisibility_data();
   void testAfterVisibility();
   void testNoQuadrupleColon();
+  void testLookaheadMatches_data();
+  void testLookaheadMatches();
 public:
   enum DumpArea {
     DumpNone = 0,
