@@ -31,12 +31,14 @@
 #include "cmakelistsparser.h"
 #include "cmaketypes.h"
 #include <language/duchain/topducontext.h>
+
 class CMakeFunctionDesc;
 
 namespace KDevelop
 {
     class TopDUContext;
     class Declaration;
+class ITestController;
 }
 
 class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
@@ -91,6 +93,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         virtual int visit( const GetPropertyAst* );
         virtual int visit( const RemoveDefinitionsAst * );
         virtual int visit( const SeparateArgumentsAst * );
+        virtual int visit( const UnsetAst * );
         virtual int visit( const WhileAst * );
         virtual int visit( const CMakeAst * );
         
@@ -113,6 +116,7 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         QList<Target> targets() const { return m_targetForId.values(); }
         QStringList resolveDependencies(const QStringList& target) const;
         QStringList includeDirectories() const { return m_includeDirectories; }
+        QList<Test> testSuites() const { return m_testSuites; }
             
         int walk(const CMakeFileContent& fc, int line, bool isClean=false);
         
@@ -200,6 +204,8 @@ class KDEVCMAKECOMMON_EXPORT CMakeProjectVisitor : CMakeAstVisitor
         KDevelop::ReferencedTopDUContext m_parentCtx;
         bool m_hitBreak;
         QMap<QString, QString> m_environmentProfile;
+
+        QList<Test> m_testSuites;
 };
 
 #endif
